Module active_note

Module active_note 

Functions

find_attachment
Searches the active note metadata for attachment_scheme.
get_assets
Get the assets of the currently executing note.
get_attachments_commitment
Returns the commitment over all attachments of the note currently executing.
get_metadata
Returns the attachment and metadata header of the note that is currently executing.
get_recipient
Returns the recipient of the note that is currently executing.
get_script_root
Returns the script root of the currently executing note.
get_sender
Returns the sender AccountId of the note that is currently executing.
get_serial_number
Returns the serial number of the currently executing note.
get_storage
Returns the storage of the currently executing note.
is_private
Returns whether the note currently executing is private.
is_public
Returns whether the note currently executing is public.
write_attachment_commitments_to_memory
Writes attachment commitments to memory and returns them as protocol words.
write_attachment_to_memory
Writes the selected attachment to memory and returns it as protocol words.