pub struct ActiveNoteAssetsInfo {
pub commitment: Word,
pub num_assets: u32,
}Expand description
Contains summary information about the assets the active note was created with.
Fields
commitment: WordThe commitment over the assets the note was created with.
num_assets: u32The number of assets the note was created with.