pub struct ActiveNoteStorageInfo {
pub commitment: Word,
pub num_storage_items: u32,
}Expand description
Contains summary information about the storage stored in the active note.
Fields
commitment: WordThe commitment over the note’s storage.
num_storage_items: u32The number of storage items the note was created with.