Module input_note

Module input_note 

Structs

InputNoteAssetsInfo
Contains summary information about the assets stored in an input note.
InputNoteStorageInfo
Contains summary information about the storage stored in an input note.

Functions

find_attachment
Searches the input note metadata for attachment_scheme.
get_assets
Returns the assets contained in the input note at note_index.
get_assets_info
Returns the assets commitment and asset count for the input note at note_index.
get_attachments_commitment
Returns the commitment over all attachments of the input note at note_index.
get_attachments_commitment_raw
Returns the attachment commitment using the protocol’s shared active/indexed input-note path.
get_metadata
Returns the attachment and metadata header of the input note at note_index.
get_recipient
Returns the recipient of the input note at note_index.
get_script_root
Returns the script root of the input note at note_index.
get_sender
Returns the sender of the input note at note_index.
get_serial_number
Returns the serial number of the input note at note_index.
get_storage_info
Returns the storage commitment and storage item count for the input note at note_index.
write_attachment_commitments_to_memory
Writes attachment commitments to memory and returns them as protocol words.
write_attachment_to_memory
Writes the selected input-note attachment to memory and returns it as protocol words.