get_attachments_commitment_raw

Function get_attachments_commitment_raw 

pub fn get_attachments_commitment_raw(
    is_active_note: Felt,
    note_index: NoteIdx,
) -> Word
Returns the attachment commitment of the active note when is_active_note is one, or of the indexed input note when it is zero.

Panics

Panics if is_active_note is neither zero nor one.