pub fn write_attachment_commitments_to_memory(note_index: NoteIdx) -> Vec<Word>Expand description
Returns the attachment commitments of the input note at note_index.
The name mirrors the kernel procedure, which fills the buffer this function returns.