Module note

Module note 

Functions

build_recipient
Builds a note recipient from the provided serial number, script root, and storage elements.
compute_and_store_recipient
Computes and stores a note recipient from serial number, script root, and storage elements.
compute_recipient
Computes a note recipient from serial number, script root, and storage commitment.
compute_storage_commitment
Computes the commitment to the provided note storage elements.
find_attachment_idx
Searches a metadata header word for attachment_scheme.
metadata_into_attachment_schemes
Extracts the four attachment schemes encoded in a note metadata header word.
metadata_into_note_type
Extracts the note type encoded in a note metadata header word.
metadata_into_sender
Extracts the sender account ID from a note metadata header word.
metadata_into_tag
Extracts the note tag encoded in a note metadata header word.
write_attachment_commitments_to_memory
Writes attachment commitments from the advice map to memory.
write_attachment_to_memory
Writes one attachment from the advice map to memory.
write_indexed_attachment_to_memory
Writes the indexed attachment from an attachment commitment list to memory.