#[repr(C)]pub struct Asset {
pub key: Word,
pub value: Word,
}Expand description
A fungible or non-fungible asset encoded as separate vault key and value words.
The key identifies the asset in the account vault and the value stores the corresponding
asset contents. This matches the v0.14 protocol/base ABI.
Fields
key: WordThe asset’s vault key.
value: WordThe asset’s vault value.
Implementations