pub struct AssetClass {
pub prefix: Felt,
pub suffix: Felt,
}Expand description
The class of an asset, composed of two field elements.
The asset class distinguishes different assets issued by the same faucet; it is empty for
fungible assets. Use AssetId::faucet_id to identify the issuer.
Fields
prefix: FeltThe prefix of the class, the second element of the kernel’s [suffix, prefix] output.
suffix: FeltThe suffix of the class, the first element of the kernel’s [suffix, prefix] output.
Implementations
Sourceimpl AssetClass
impl AssetClass
Sourcepub fn new(prefix: Felt, suffix: Felt) -> Self
pub fn new(prefix: Felt, suffix: Felt) -> Self
Creates a new AssetClass from prefix and suffix Felt values.