Functions
- find_
attachment - Searches the active note metadata for
attachment_scheme. - get_
assets - Get the assets of the currently executing note.
- get_
attachments_ commitment - Returns the commitment over all attachments of the note currently executing.
- get_
metadata - Returns the attachment and metadata header of the note that is currently executing.
- get_
recipient - Returns the recipient of the note that is currently executing.
- get_
script_ root - Returns the script root of the currently executing note.
- get_
sender - Returns the sender
AccountIdof the note that is currently executing. - get_
serial_ number - Returns the serial number of the currently executing note.
- get_
storage - Returns the storage of the currently executing note.
- is_
private - Returns whether the note currently executing is private.
- is_
public - Returns whether the note currently executing is public.
- write_
attachment_ commitments_ to_ memory - Writes attachment commitments to memory and returns them as protocol words.
- write_
attachment_ to_ memory - Writes the selected attachment to memory and returns it as protocol words.