Structs
- Input
Note Assets Info - Contains summary information about the assets stored in an input note.
- Input
Note Storage Info - Contains summary information about the storage stored in an input note.
Functions
- find_
attachment - Searches the input note metadata for
attachment_scheme. - get_
assets - Returns the assets contained in the input note at
note_index. - get_
assets_ info - Returns the assets commitment and asset count for the input note at
note_index. - get_
attachments_ commitment - Returns the commitment over all attachments of the input note at
note_index. - get_
attachments_ commitment_ raw - Returns the attachment commitment using the protocol’s shared active/indexed input-note path.
- get_
metadata - Returns the attachment and metadata header of the input note at
note_index. - get_
recipient - Returns the recipient of the input note at
note_index. - get_
script_ root - Returns the script root of the input note at
note_index. - get_
sender - Returns the sender of the input note at
note_index. - get_
serial_ number - Returns the serial number of the input note at
note_index. - get_
storage_ info - Returns the storage commitment and storage item count for the input note at
note_index. - write_
attachment_ commitments_ to_ memory - Writes attachment commitments to memory and returns them as protocol words.
- write_
attachment_ to_ memory - Writes the selected input-note attachment to memory and returns it as protocol words.