Module input_note

Module input_note 

Structs

InputNoteAssetsInfo
Contains summary information about the assets stored in an input note.
InputNoteStorageInfo
Contains summary information about the storage stored in an input note.

Functions

get_assets
Returns the assets contained in the input note at note_index.
get_assets_info
Returns the assets commitment and asset count for the input note at note_index.
get_metadata
Returns the attachment and metadata header of the input note at note_index.
get_recipient
Returns the recipient of the input note at note_index.
get_script_root
Returns the script root of the input note at note_index.
get_sender
Returns the sender of the input note at note_index.
get_serial_number
Returns the serial number of the input note at note_index.
get_storage_info
Returns the storage commitment and storage item count for the input note at note_index.