Functions
- build_
recipient - Builds a note recipient from the provided serial number, script root, and storage elements.
- compute_
and_ store_ recipient - Computes and stores a note recipient from serial number, script root, and storage elements.
- compute_
recipient - Computes a note recipient from serial number, script root, and storage commitment.
- compute_
storage_ commitment - Computes the commitment to the provided note storage elements.
- find_
attachment_ idx - Searches a metadata header word for
attachment_scheme. - metadata_
into_ attachment_ schemes - Extracts the four attachment schemes encoded in a note metadata header word.
- metadata_
into_ note_ type - Extracts the note type encoded in a note metadata header word.
- metadata_
into_ sender - Extracts the sender account ID from a note metadata header word.
- metadata_
into_ tag - Extracts the note tag encoded in a note metadata header word.
- write_
attachment_ commitments_ to_ memory - Writes attachment commitments from the advice map to memory.
- write_
attachment_ to_ memory - Writes one attachment from the advice map to memory.
- write_
indexed_ attachment_ to_ memory - Writes the indexed attachment from an attachment commitment list to memory.