pub fn load_attachment_commitments(attachments_commitment: Word) -> Vec<Word>Expand description
Loads the attachment commitments committed to by attachments_commitment from the advice map.
The advice map must contain the preimage committed to by attachments_commitment.
Panics
Panics if the preimage is not a whole number of words or holds more commitments than a note can have attachments.