pub fn write_attachment_commitments_to_memory(
attachments_commitment: Word,
) -> Vec<Word>Expand description
Writes attachment commitments from the advice map to memory.
The advice map must contain the preimage committed to by attachments_commitment.