pub fn write_attachment_to_memory(attachment_commitment: Word) -> Vec<Word>
Writes one attachment from the advice map to memory.
The advice map must contain the attachment elements committed to by attachment_commitment.
attachment_commitment