#[repr(C)]pub struct Asset {
pub id: AssetId,
pub value: Word,
}Expand description
A fungible or non-fungible asset encoded as an asset id and a value word.
The id identifies the asset in a vault (issuing faucet, asset class, composition rule);
value is the asset contents.
Fields
id: AssetIdThe asset’s id, which identifies it in a vault.
value: WordThe asset’s contents.
Implementations
Sourceimpl Asset
impl Asset
Sourcepub fn new(id: impl Into<AssetId>, value: impl Into<Word>) -> Self
pub fn new(id: impl Into<AssetId>, value: impl Into<Word>) -> Self
Creates a new Asset from its id and value word.
Sourcepub fn amount(&self) -> AssetAmount
pub fn amount(&self) -> AssetAmount
Returns this asset’s fungible amount.
The composition rule is read from the asset id with AssetId::composition, which
executes the protocol library’s asset::id_into_composition procedure.
Panics
Panics if the composition bits of the asset id hold an unrecognized value, if the asset is
not fungible, or if its amount exceeds AssetAmount::MAX_U64.
Sourcepub fn is_fungible(&self) -> bool
pub fn is_fungible(&self) -> bool
Returns true if this asset is fungible.
The composition rule is read from the asset id with AssetId::composition, which
executes the protocol library’s asset::id_into_composition procedure.
Panics
Panics if the composition bits of the asset id hold an unrecognized value.