Asset

Struct Asset 

#[repr(C)]
pub struct Asset { pub key: Word, pub value: Word, }
A fungible or non-fungible asset encoded as separate vault key and value words.

The key identifies the asset in the account vault and the value stores the corresponding asset contents. This matches the v0.14 protocol/base ABI.

Fields

key: Word

The asset’s vault key.

value: Word

The asset’s vault value.

Implementations

Source

impl Asset

pub fn new(key: impl Into<Word>, value: impl Into<Word>) -> Self

Creates a new Asset from its key and value words.